import argparse

import ddgr
import fzf

PARSER = argparse.ArgumentParser(description='Search duckduckgo, select result with fzf and write result to stdout')
PARSER.add_argument('query', nargs="*")
args = PARSER.parse_args()


def main():
    opts = ddgr.parse_args(args.query)
    ddgr.DdgCmd.colors = []
    cmd = ddgr.DdgCmd(opts, "ddgz")
    cmd.fetch()
    chosen, = fzf.fzf([r.title for r in cmd.results])
    print(cmd.results[chosen.index].url)



import setuptools
import distutils.core

setuptools.setup(
    name='ddgz',
    version="1.0.0",
    author='talwrii',
    long_description_content_type='text/markdown',
    author_email='talwrii@gmail.com',
    description='Search with duckduckgo from the command-line, fuzzy select the results.',
    license='MIT',
    keywords='duckduckgo,search',
    url='https://github.com/talwrii/ddgz',
    install_requires=["ddgr", "python-fzf"],
    packages=["ddgz"],
    long_description=open('README.md').read(),
    entry_points={
        'console_scripts': ['ddgz=ddgz.main:main']
    },
)
